package br.com.evologica.mvp.data;

import android.content.Context;

import com.androidnetworking.common.ANRequest;

import org.json.JSONException;
import org.json.JSONObject;

import br.com.evologica.mvp.data.db.AppDbHelper;
import br.com.evologica.mvp.data.db.DbHelper;
import br.com.evologica.mvp.data.db.model.Sensor;
import br.com.evologica.mvp.data.db.model.Stream;
import br.com.evologica.mvp.data.db.model.StreamData;
import br.com.evologica.mvp.data.network.ApiHelper;
import br.com.evologica.mvp.data.network.AppApiHelper;
import br.com.evologica.mvp.data.prefs.AppPreferencesHelper;
import br.com.evologica.mvp.data.prefs.PreferencesHelper;
import br.com.evologica.mvp.utils.AppConstants;

/**
 * Created by marcussales on 01/03/2017.
 */

public class AppDataManager implements DataManager {

    private static final String TAG = "AppDataManager";

    private final Context mContext;
    private PreferencesHelper mPreferencesHelper;
    private ApiHelper mApiHelper;
    private DbHelper mDbHelper;

    public AppDataManager(Context ctx) {
        mContext = ctx;
        mPreferencesHelper = new AppPreferencesHelper(ctx, AppConstants.PREF_NAME);
        mApiHelper = new AppApiHelper();
        mDbHelper = new AppDbHelper();
    }

    @Override
    public void setLoggedIn() {
        mPreferencesHelper.setLoggedIn();
    }

    @Override
    public void setLoggedOut() {
        mPreferencesHelper.setLoggedOut();
    }

    @Override
    public boolean isLogged() {
        return mPreferencesHelper.isLogged();
    }

    @Override
    public ANRequest getAllStreams() {
        return mApiHelper.getAllStreams();
    }

    @Override
    public ANRequest getDetailSensor(int oidSensor) {
        return mApiHelper.getDetailSensor(oidSensor);
    }

    @Override
    public ANRequest getDetailStream(int oidSensor, int oidStream) {
        return mApiHelper.getDetailStream(oidSensor, oidStream);
    }

    @Override
    public Sensor createSensor(JSONObject jsonObject) throws JSONException {
        return mDbHelper.createSensor(jsonObject);
    }

    @Override
    public Stream createStream(JSONObject jsonObject) throws JSONException {
        return mDbHelper.createStream(jsonObject);
    }

    @Override
    public StreamData createStreamData(JSONObject jsonObject) throws JSONException {
        return mDbHelper.createStreamData(jsonObject);
    }
}
