package br.com.evologica.mvp.ui.detailSensor;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.MenuItem;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.TextView;

import java.util.List;

import br.com.evologica.mvp.MvpApp;
import br.com.evologica.mvp.R;
import br.com.evologica.mvp.data.db.model.Stream;

/**
 * Created by marcussales on 02/10/2017.
 */

public class DetailSensorActivity extends AppCompatActivity implements DetailSensorMvpView {

    DetailSensorMvpPresenter<DetailSensorMvpView> mPresenter;

    private RecyclerView listaStreams;
    private TextView errorText;
    private ProgressBar progressBar;

    private int sensorOid;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_detail_sensor);

        listaStreams = (RecyclerView) findViewById(R.id.list_streams);
        errorText = (TextView) findViewById(R.id.error_text);
        progressBar = (ProgressBar) findViewById(R.id.progress_bar);
        Toolbar detailToolbar = (Toolbar) findViewById(R.id.toolbar_detail);

        String sensorName = getIntent().getStringExtra("SENSOR_NAME");
        detailToolbar.setTitle(sensorName);
        setSupportActionBar(detailToolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        mPresenter = new DetailSensorPresenter<>(((MvpApp)getApplicationContext()).getDataManager());
        mPresenter.onAttach(this);

        sensorOid = getIntent().getIntExtra("SENSOR_OID", 0);
        mPresenter.fetchStreams(sensorOid);

    }

    @Override
    protected void onDestroy() {
        mPresenter.onDetach();
        super.onDestroy();
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch(item.getItemId()){
            case android.R.id.home:
                finish();
                break;
        }
        return true;
    }

    @Override
    public void onFetchStreamsFinished(List<Stream> streams) {
        progressBar.setVisibility(View.GONE);
        listaStreams.setVisibility(View.VISIBLE);
        StreamsAdapter adapter = new StreamsAdapter(streams, this, sensorOid);
        listaStreams.setLayoutManager(new LinearLayoutManager(this));
        listaStreams.setAdapter(adapter);
    }

    @Override
    public void onErrorFetchStreams(String message) {
        progressBar.setVisibility(View.GONE);
        errorText.setVisibility(View.VISIBLE);
        errorText.setText(message);
    }
}
