package br.com.evologica.mvp.ui.detailStream;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.MenuItem;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.TextView;

import java.util.List;

import br.com.evologica.mvp.MvpApp;
import br.com.evologica.mvp.R;
import br.com.evologica.mvp.data.db.model.StreamData;

/**
 * Created by marcussales on 02/10/2017.
 */

public class DetailStreamActivity extends AppCompatActivity implements DetailStreamMvpView {

    DetailStreamMvpPresenter<DetailStreamMvpView> mPresenter;

    private RecyclerView listaStreamData;
    private TextView errorText;
    private ProgressBar progressBar;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_detail_streams);

        listaStreamData = (RecyclerView) findViewById(R.id.list_stream_data);
        errorText = (TextView) findViewById(R.id.error_text);
        progressBar = (ProgressBar) findViewById(R.id.progress_bar);
        Toolbar detailStreamToolbar = (Toolbar) findViewById(R.id.toolbar_detail_stream);

        detailStreamToolbar.setTitle("Stream");
        setSupportActionBar(detailStreamToolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);


        mPresenter = new DetailStreamPresenter<>(((MvpApp)getApplicationContext()).getDataManager());
        mPresenter.onAttach(this);

        int sensorOid = getIntent().getIntExtra("SENSOR_OID", 0);
        int streamOid = getIntent().getIntExtra("STREAM_OID", 0);

        mPresenter.fetchStreamsData(sensorOid, streamOid);
    }

    @Override
    protected void onDestroy() {
        mPresenter.onDetach();
        super.onDestroy();
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch(item.getItemId()){
            case android.R.id.home:
                finish();
                break;
        }
        return true;
    }

    @Override
    public void onFetchStreamsDataFinished(List<StreamData> response) {
        progressBar.setVisibility(View.GONE);
        listaStreamData.setVisibility(View.VISIBLE);
        StreamDataAdapter adapter = new StreamDataAdapter(response, this);
        listaStreamData.setLayoutManager(new LinearLayoutManager(this));
        listaStreamData.setAdapter(adapter);
    }

    @Override
    public void onErrorFetchStreamsData(String message) {
        progressBar.setVisibility(View.GONE);
        errorText.setVisibility(View.VISIBLE);
        errorText.setText(message);
    }
}
