package br.com.evologica.mvp.ui.main;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.TextView;

import java.util.List;

import br.com.evologica.mvp.MvpApp;
import br.com.evologica.mvp.R;
import br.com.evologica.mvp.data.db.model.Sensor;

/**
 * Created by marcussales on 01/03/2017.
 */

public class MainActivity extends AppCompatActivity implements MainMvpView {

    MainMvpPresenter<MainMvpView> mPresenter;

    private RecyclerView listaSensores;
    private TextView errorText;
    private ProgressBar progressBar;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        listaSensores = (RecyclerView) findViewById(R.id.list_sensor);
        errorText = (TextView) findViewById(R.id.error_text);
        progressBar = (ProgressBar) findViewById(R.id.progress_bar);
        Toolbar mainToolbar = (Toolbar) findViewById(R.id.toolbar_main);

        mainToolbar.setTitle("Sensores");
        setSupportActionBar(mainToolbar);

        mPresenter = new MainPresenter<>(((MvpApp)getApplicationContext()).getDataManager());
        mPresenter.onAttach(MainActivity.this);
        mPresenter.fetchSensors();
    }

    @Override
    protected void onDestroy() {
        mPresenter.onDetach();
        super.onDestroy();
    }

    @Override
    public void onFetchSensorsFinished(List<Sensor> sensores) {
        progressBar.setVisibility(View.GONE);
        listaSensores.setVisibility(View.VISIBLE);
        SensoresAdapter adapter = new SensoresAdapter(sensores, this);
        listaSensores.setLayoutManager(new LinearLayoutManager(this));
        listaSensores.setAdapter(adapter);
    }

    @Override
    public void onErrorFetchSensors(String message) {
        progressBar.setVisibility(View.GONE);
        errorText.setVisibility(View.VISIBLE);
        errorText.setText(message);
    }
}
